/*
* au-string.h - Header file for au-string.c
* Copyright (c) 2014 Red Hat Inc., Durham, North Carolina.
* All Rights Reserved.
*
* This software may be freely redistributed and/or modified under the
* terms of the GNU General Public License as published by the Free
* Software Foundation; either version 2, or (at your option) any
* later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; see the file COPYING. If not, write to the
* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* Authors:
*   Steve Grubb <sgrubb@redhat.com>
*/

#ifndef AUSTRING_HEADER
#define AUSTRING_HEADER

typedef enum { FIELD_LITERAL, FIELD_LOOKUP, FIELD_INTERPRET, FIELD_VIRTUAL,
	FIELD_CLASSIFIED } types_t;

/* This is the node of the linked list. message & item are the only elements
 * at this time. Any data elements that are per item goes here. */
typedef struct _snode{
  types_t type; 	// The type of field 
  const char *str;	// The string or field to be looked up
  struct _snode* next;	// Next string node pointer
} snode;

/* This is the linked list head. Only data elements that are 1 per
 * event goes here. */
typedef struct {
  snode *head;		// List head
  snode *cur;		// Pointer to current node
  unsigned int cnt;	// How many items in this list
} slist;

void slist_create(slist *l);
static inline void slist_first(slist *l) { l->cur = l->head; }
snode *slist_next(slist *l);
static inline snode *slist_get_cur(slist *l) { return l->cur; }
void slist_clear(slist* l);
int slist_load(slist *l, char *f);
void slist_dump(slist *l);

#endif

